@@ -1,7 +1,7 @@
-import schedule
 from sleepyask.openai.chatgpt import ask_questions
 import traceback
 import logging
+import time
 
 def ask(configs : list, questions : list, output_file_path : str, verbose: bool = False, model : str = "gpt-3.5-turbo"):
     '''
@@ -9,6 +9,18 @@ def ask(configs : list, questions : list, output_file_path : str, verbose: bool
     `questions` should contain a list of questions you would like ChatGPT to answer.\n
     `output_file_path` should be the file path where you would like your responses to be saved.\n
     '''
+<<<<<<< HEAD
+
+    while True:
+        if not isinstance(questions, list): raise ValueError("[questions] should be a list")
+        def func() -> None:
+            try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose)
+            except Exception as e: logging.error(traceback.format_exc())
+        
+        func()
+        time.sleep(60)
+        
+=======
     if not isinstance(questions, list): raise ValueError("[questions] should be a list")
     def func() -> None:
         try: ask_questions(configs=configs, questions=questions, output_file_path=output_file_path, verbose=verbose, model=model)
@@ -19,3 +31,4 @@ def ask(configs : list, questions : list, output_file_path : str, verbose: bool
 
     func()
     while True: schedule.run_pending()
+>>>>>>> e47803844bf417502f73e4468b25b13f32134d93
